﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)
         
    mr = MusicRoom(fadeout=1.0)
    mr.add("track1.ogg")


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window:
        has vbox

        text prompt
        input id "input"

    use quick_menu

screen acerca_de:

    tag menu

    frame:        
        
        viewport id "acerca_de":             
             has vbox

             text ".heartbeats was developed with the Ren'Py engine (designed to develop visual novels in Python).\n"                          
        
             text "The game was completely coded and written in two languages by a single person (me): Sebastian Trelles. From the basic music to the heart beats and the text were all created by him. Sound effects were taken from youtube videos. And as simple as it may seem... COORDINATING THE SOUND EFFECTS WITH THE MUSIC HAS BEEN GODDAMN IMPOSSIBLE!!! However, I'm quite happy as to how it turned out to be."
             
             text "\nAbout the game... I simply wanted to tell a story involving life's hardships, drama, and an interesting narrative, centered in emotion and decisions. I hope you'll enjoy the game as much as I enjoyed coding it (minus the nights I didn't sleep).\n"
             
             text "Contact info:"
             text "{b}Email{/b}: strelles@gmail.com"
             text "{b}Webpage{/b}: http://theadventuregamer.blogspot.com\n"
             
             # The button that lets the user exit the music room.
             textbutton "Main Menu" action ShowMenu("main_menu")
                     
        vbar value YScrollValue("acerca_de") bar_invert True xalign 1.0    
    
screen music_room:

    tag menu

    frame:        
        
        viewport id "tips":             
             has vbox

             text "This is the game's tips section.\nTips will pop up here as you start unlocking {color=#FF0000}{b}key{/b}{/color} words.\n\n"
             
             text "{color=#FF0000}{b}How the game works{/b}{/color}: \nThe game tells the story of three people in three different moments in life. The story starts with the first event (Xavier's), then follows with the second event (Raoul's) and ends with the third one (Maria's)."
             
             text "\nApart from the chronological order, the {b}heart beat indicators each correspond to one of the characters{/b},and indicate the chances that character may or may not survive. A heart beating to slow means the character may be about to die. A heart beating too fast means the character may do something terrible, or even trigger another character's death."
             
             text "\nSounds also take part in the game. Whenever a beat is accompanied by a beep, it means that the corresponding character is present in the scene. \n\n"
             
             
             text "{color=#FFFF00}{b}Basic Xavier{/b}{/color}: Xavier is a teenager with the burden of being different. You should cheer him up and make him get some help, so that he does not make an unmendable mistake.\n"
        
             text "{color=#0000FF}{b}Basic Raoul{/b}{/color}: Raoul is a young adult who drinks and loses sight of what's dear to him. You must help him earn back the trust from his ex-girlfriend.\n"
        
             text "{color=#FF0000}{b}Basic Maria{/b}{/color}: Maria is an adult woman who has temporal amnesia, as she passed out and hit her head. Help her recover and face what's about to come.\n"
            
             $epilogo=False
             for texto in persistent.key_words:
                 
                 if texto=="consejo":
                     text ("{color=#FFFF00}Advice{/color}: Xavier has mentioned he believes he can give useful advice. If someone ever needs some help, it may be a good idea to ask for it.\n")
                 elif texto=="hermano":
                     text ("{color=#FFFF00}Brother{/color}: Xavier has said he has a brother, with whom he lost contact. \n")
                 elif texto=="madurar":
                     text ("{color=#FFFF00}Mature{/color}: Xavier has said he would like to mature. Will he be able to accomplish that?\n")
                 elif texto=="direccionContraria":
                     text ("{color=#FFFF00}Opposite way{/color}: Xavier has said he feels he walks in the opposite way compared of the rest of the world. Hmmm...\n")
                 elif texto=="medicina":
                     text ("{color=#FFFF00}Medicine{/color}: Xavier has mentioned he would like to study medicine when he grows up. Curious... given that one of the game's characters is a doctor.\n")
                 elif texto=="diferente":
                     text ("{color=#FFFF00}Being different{/color}: Xavier believes he's different than the rest of the people. Hmmm...\n")
                     
                 elif texto=="recuperarla":
                     text ("{color=#0000FF}Win her back{/color}: Raoul is decided to win back Maria. And for that matter, he has asked Xavier for advice. Will they be able to attain what they desire?\n")
                 elif texto=="viaje":
                     text ("{color=#0000FF}Trip{/color}: Raouls says to have went on a trip with Maria, to a distant town. This memory seems important to both of them. Let's write this down...\n")
                 elif texto=="error":
                     text ("{color=#0000FF}Error{/color}: Raoul says to have made a terrible mistake in his relationship with Maria. Now that he has managed to understand the whole thing, things will be easier for him.")
                 elif texto=="perdida":
                     text ("{color=#0000FF}Lost{/color}: If Raoul loses his cool into winning back Maria, he will lose her forever. Sometimes, it may be better to wait and see...\n")
                 elif texto=="equivocado":
                     text ("{color=#0000FF}Married{/color}: The woman of the third event is actually married. Now, how does this relate to the other stories?\n")
                 elif texto=="aprenderDeSusErrores":
                     text ("{color=#0000FF}Park{/color}: Maria and Raoul came to this park the first day they met. They both hold precious memories of this place.\n")
                     text ("{color=#0000FF}Learning from mistakes{/color}: That's what Raoul asks from Maria, for her to let him learn from his mistakes.\n")
                     
                 elif texto=="profesora":
                     text ("{color=#FF0000}Teacher{/color}: Maria says she's a Social Sciences teacher. She has studied at the Faculty of Humanities.\n")                     
                 elif texto=="marido":
                     text ("{color=#FF0000}Husband{/color}: Maria thinks she's married. Maybe this relates to some other event...? Hmm...\n")
                 elif texto=="sinMedicamentos":
                     text ("{color=#FF0000}No medicine{/color}: Maria didn't want to take any medicine, even though she was feeling sick. Wonder why..\n")
                     
                 elif texto=="perdonado":
                     text ("{color=#FF0000}Second Chance{/color}: Maria gave Raoul a second chance. And this... changed Raoul's life forever.\n")    
                     
                 elif texto=="epilogue":
                     $epilogo=True    
                     

             if epilogo:
                  text ("{color=#FF0000}{b}Epilogue{/b}{/color}: A picnic on the countryside. Xavier, Maria, Raoul and their daughter enjoying life. This is the game's best ending. And the most important message it wants to communicate. Congratulations.\n")
                  
             # The button that lets the user exit the music room.
             textbutton "Main Menu" action ShowMenu("main_menu")
                     
        vbar value YScrollValue("tips") bar_invert True xalign 1.0
    
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:
    tag menu

    if persistent.endings_unlocked == True:
        use main_menu_special    
    else:
        use main_menu_default

screen main_menu_default:

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()                        
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("About") action ShowMenu("acerca_de")
        textbutton _("Quit") action Quit(confirm=False)
        
screen main_menu_special:

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()
        textbutton _("Tips") action ShowMenu("music_room") #ShowMenu("tips")
        textbutton _("Preferences") action ShowMenu("preferences")        
        textbutton _("About") action ShowMenu("acerca_de")
        textbutton _("Quit") action Quit(confirm=False)        

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98
        
        has vbox

        textbutton _("Return") action Return()        
        textbutton _("Quit") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    # Format the description, and add it as text.
                    $ description = "% 2s. %s\n%s" % (
                        FileSlotName(i, columns * rows),
                        FileTime(i, empty=_("Empty Slot.")),
                        FileSaveName(i))

                    text description

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)

    

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                label _("Voice Volume")
                bar value Preference("voice volume")

                if config.sample_voice:
                    textbutton "Test":
                        action Play("voice", config.sample_voice)
                        style "soundtest_button"

screen tips:    
    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                label _("Voice Volume")
                bar value Preference("voice volume")

                if config.sample_voice:
                    textbutton "Test":
                        action Play("voice", config.sample_voice)
                        style "soundtest_button"             
                        
init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 1.0
        yalign 1.0
        
        textbutton _("Auto") action Preference("auto-forward", "toggle")        
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Main Menu") action MainMenu(confirm=True)
        textbutton _("Quit") action Quit(confirm=True)
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    